SysPhantom

Enum SysPhantom 

#[repr(u16)]
pub enum SysPhantom { Nop = 0, DebugPanic = 1, CtStart = 2, CtEnd = 3, }
Phantom instructions owned by the system. These are handled in the ExecutionSegment, as opposed to the PhantomChip.

Variants



Nop = 0

Does nothing at constraint and runtime level besides advance pc by DEFAULT_PC_STEP.



DebugPanic = 1

Causes the runtime to panic, on host machine and prints a backtrace.



CtStart = 2

Start tracing



CtEnd = 3

End tracing

Implementations

Source

impl SysPhantom

pub const fn from_repr(discriminant: u16) -> Option<SysPhantom>

Try to create Self from the raw representation